@@ -84,6 +84,7 @@ struct _PtkFileBrowser
     gboolean busy : 1;
     gboolean pending_drag_status : 1;
     dev_t drag_source_dev;
+    ino_t drag_source_inode;
     int drag_x;
     int drag_y;
     gboolean pending_drag_status_tree : 1;
@@ -105,9 +106,6 @@ struct _PtkFileBrowser
     GtkWidget* mynotebook;
     GtkWidget* task_view;
     gpointer main_window;
-    int* slide_x;
-    int* slide_y;
-    int* slide_s;
     GtkWidget* toolbox;
     GtkWidget* path_bar;
     GtkWidget* hpane;
@@ -171,11 +169,7 @@ GType ptk_file_browser_get_type ( void );
 
 GtkWidget* ptk_file_browser_new( int curpanel, GtkWidget* notebook,
                                                     GtkWidget* task_view,
-                                                    gpointer main_window,
-                                                    int* slide_x,
-                                                    int* slide_y,
-                                                    int* slide_s );
-
+                                                    gpointer main_window );
 
 /*
 * folder_path should be encodede in on-disk encoding
@@ -321,8 +315,8 @@ void ptk_file_browser_grab_pathbar( GtkMenuItem *menuitem, PtkFileBrowser* file_
 void ptk_file_browser_go_tab( GtkMenuItem *item, PtkFileBrowser* file_browser,
                                                                         int t );
 void ptk_file_browser_focus( GtkMenuItem *item, PtkFileBrowser* file_browser, int job2 );
-void on_folder_view_columns_changed( GtkTreeView *view,
-                                                PtkFileBrowser* file_browser );
+void ptk_file_browser_save_column_widths( GtkTreeView *view,
+                                PtkFileBrowser* file_browser, gboolean force );
 
 void ptk_file_browser_test_exec( GtkWidget* item, PtkFileBrowser* file_browser );
 gboolean ptk_file_browser_slider_release( GtkWidget *widget,
@@ -346,7 +340,8 @@ void ptk_file_browser_on_action( PtkFileBrowser* browser, char* setname );
 GList* folder_view_get_selected_items( PtkFileBrowser* file_browser,
                                               GtkTreeModel** model );
 void ptk_file_browser_status_change( PtkFileBrowser* file_browser, gboolean panel_focus );
-void ptk_file_browser_select_file( PtkFileBrowser* file_browser, char* path );
+void ptk_file_browser_select_file( PtkFileBrowser* file_browser,
+                                                            const char* path );
 void ptk_file_browser_select_file_list( PtkFileBrowser* file_browser,
                                                         char** filename,
                                                         gboolean do_select );
